@@ -4,20 +4,27 @@ from typing import Literal, Type, TypeVar
 from pydantic import BaseSettings
 
 
-class LoggingConfig(BaseSettings):
-    format: Literal["console", "json"] = "console"
+class AuthConfig(BaseSettings):
+    url: str
+    cookie_domain: str
+    pubkey_path: str
 
 
 class DatabaseConfig(BaseSettings):
     url: str
 
 
+class LoggingConfig(BaseSettings):
+    format: Literal["console", "json"] = "console"
+
+
 AnyConfig = TypeVar("AnyConfig", bound=BaseSettings)
-ChloreConfig = TypeVar("ChloreConfig", LoggingConfig, DatabaseConfig)
+ChloreConfig = TypeVar("ChloreConfig", AuthConfig, LoggingConfig, DatabaseConfig)
 
 
 @dataclass
 class _InternalConfig:
+    auth: AuthConfig = None
     logging: LoggingConfig = None
     database: DatabaseConfig = None
 
@@ -26,6 +33,7 @@ class _InternalConfig:
 
     def register(self, type: Type[ChloreConfig], value: ChloreConfig):
         table = {
+            AuthConfig: "auth",
             LoggingConfig: "logging",
             DatabaseConfig: "database",
         }
